@@ -9,7 +9,7 @@ from toolkit.scaffold.project.template import TEMPLATE_GOLANG_PATH
 
 create_web = generate_create_project_command(
     command_help="Create a golang web project scaffold.",
-    template_path=TEMPLATE_GOLANG_PATH / "web",
+    template_paths=TEMPLATE_GOLANG_PATH / "web",
     generated_path_hook=golang_generated_path_hook,
     raw_user_input_context=USER_INPUT_CONTEXT | GOLANG_USER_INPUT_CONTEXT,
     user_input_context_hook=golang_user_input_context_hook,
